@@ -12,9 +12,9 @@ use strict;
 use warnings;
 use Carp;
 use CBOR::XS qw(encode_cbor decode_cbor);
-use base qw/Tie::Array/;
+use base 'Tie::Array';
 
-our $VERSION = '0.001';    # VERSION
+our $VERSION = '0.002';    # VERSION
 
 sub TIEARRAY {
     my ( $class, $redis, $listname ) = @_;
@@ -99,7 +99,7 @@ Tie::Redis::Candy::Array - tie Perl arrays to Redis lists - the candy way
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSYS
 
@@ -145,6 +145,6 @@ This software is Copyright (c) 2015 by David Zurborg.
 
 This is free software, licensed under:
 
-  The ISC License
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
